@@ -12,7 +12,7 @@ from cryptoadvance.specter.util.reflection import get_template_static_folder
 from dotenv import load_dotenv
 from flask import Flask, jsonify, redirect, request, session, url_for
 from flask_apscheduler import APScheduler
-from flask_babel import Babel
+from .htmlsafebabel import HTMLSafeBabel
 from flask_login import LoginManager, login_user
 from flask_wtf.csrf import CSRFProtect
 from jinja2 import select_autoescape
@@ -102,6 +102,8 @@ def create_app(config=None):
     logger.info(f"SPECTER_DATA_FOLDER: {app.config['SPECTER_DATA_FOLDER']}")
     # Might be convenient to know later where it came from (see Service configuration)
     app.config["SPECTER_CONFIGURATION_CLASS_FULLNAME"] = config_name
+    if not app.config.get("ENABLE_WERZEUG_REQUEST_LOGGING"):
+        logging.getLogger("werkzeug").disabled = True
     app.wsgi_app = ProxyFix(
         app.wsgi_app, x_for=1, x_proto=1, x_host=1, x_port=1, x_prefix=1
     )
@@ -220,7 +222,7 @@ def init_app(app: SpecterFlask, hwibridge=False, specter=None):
         app.config["BABEL_TRANSLATION_DIRECTORIES"] = os.path.join(
             sys._MEIPASS, "translations"
         )
-    babel = Babel(app)
+    babel = HTMLSafeBabel(app)
 
     @babel.localeselector
     def get_language_code():
