@@ -8,7 +8,6 @@ from flask import (
     redirect,
     url_for,
     jsonify,
-    flash,
 )
 from flask_babel import lazy_gettext as _
 from flask_login import login_required, current_user
@@ -17,6 +16,7 @@ from ..rpc import get_default_datadir
 from ..node import Node
 from ..specter_error import ExtProcTimeoutException
 from ..util.shell import get_last_lines_from_file
+from ..server_endpoints import flash
 
 logger = logging.getLogger(__name__)
 
@@ -140,6 +140,7 @@ def node_settings(node_alias):
                 protocol,
                 node.external_node,
                 node.fullpath,
+                "BTC",
                 node.manager,
             )
             test = node.test_rpc()
@@ -170,6 +171,7 @@ def node_settings(node_alias):
                         rand=rand,
                     )
                 node = app.specter.node_manager.add_node(
+                    "BTC",
                     node.name,
                     autodetect,
                     datadir,
