@@ -1,4 +1,3 @@
-import cryptography
 import json
 import logging
 import os
@@ -12,16 +11,14 @@ import time
 import zipfile
 from pathlib import Path
 
+import cryptography
 import pgpy
 import requests
 from flask import Blueprint, Flask
 from flask import current_app as app
-from flask import flash, jsonify, redirect, render_template, request, send_file, url_for
+from flask import jsonify, redirect, render_template, request, send_file, url_for
 from flask_babel import lazy_gettext as _
 from flask_login import current_user, login_required
-from cryptoadvance.specter.services.service import Service
-
-from cryptoadvance.specter.user import User, UserSecretException
 
 from ..helpers import (
     get_loglevel,
@@ -30,7 +27,10 @@ from ..helpers import (
     set_loglevel,
 )
 from ..persistence import write_devices, write_wallet
-from ..specter_error import ExtProcTimeoutException, handle_exception
+from ..server_endpoints import flash
+from ..services.service import callbacks
+from ..specter_error import handle_exception
+from ..user import UserSecretException
 from ..util.sha256sum import sha256sum
 from ..util.shell import get_last_lines_from_file
 from ..util.tor import start_hidden_service, stop_hidden_services
@@ -43,6 +43,17 @@ rand = random.randint(0, 1e32)  # to force style refresh
 settings_endpoint = Blueprint("settings_endpoint", __name__)
 
 
+@settings_endpoint.context_processor
+def inject_common_stuff():
+    """Can be used in all jinja2 templates of this Blueprint
+    Injects the additional settings_tabs via extentions
+    """
+    ext_settingstabs = app.specter.service_manager.execute_ext_callbacks(
+        callbacks.add_settingstabs
+    )
+    return dict(ext_settingstabs=ext_settingstabs)
+
+
 @settings_endpoint.route("/", methods=["GET"])
 @login_required
 def settings():
@@ -118,7 +129,8 @@ def general():
             app.specter.update_merkleproof_settings(
                 validate_bool=validate_merkleproof_bool
             )
-            app.specter.service_manager.set_active_services(active_services)
+            if current_user.is_admin:
+                app.specter.service_manager.set_active_services(active_services)
             app.specter.update_fee_estimator(
                 fee_estimator=fee_estimator,
                 custom_url=fee_estimator_custom_url,
