@@ -1,41 +1,45 @@
 import csv
 import json
 import logging
+import re
+import threading
 import time
 from binascii import b2a_base64
 from datetime import datetime
 from io import StringIO
 from math import isnan
 from numbers import Number
-import re
 
 import requests
-from cryptoadvance.specter.commands.psbt_creator import PsbtCreator
-from cryptoadvance.specter.wallet import Wallet
-from flask import Blueprint, stream_with_context
+from embit.descriptor.checksum import add_checksum
+from flask import Blueprint
 from flask import current_app as app
-from flask import flash, jsonify, redirect, request, url_for
-from flask_babel import lazy_gettext as _
+from flask import jsonify, redirect, request, stream_with_context, url_for
 from flask_babel import lazy_gettext
+from flask_babel import lazy_gettext as _
 from flask_login import current_user, login_required
 from werkzeug.wrappers import Response
 
+from ..commands.psbt_creator import PsbtCreator
 from ..helpers import bcur2base64
-from ..util.mnemonic import generate_mnemonic
 from ..rpc import RpcError
+from ..server_endpoints import flash
 from ..server_endpoints.filters import assetlabel
 from ..specter_error import SpecterError, handle_exception
 from ..util.base43 import b43_decode
 from ..util.descriptor import Descriptor
 from ..util.fee_estimation import FeeEstimationResultEncoder, get_fees
+from ..util.mnemonic import generate_mnemonic
 from ..util.price_providers import get_price_at
 from ..util.tx import decoderawtransaction
-from embit.descriptor.checksum import add_checksum
+from ..wallet import Wallet
 
 logger = logging.getLogger(__name__)
 
 wallets_endpoint_api = Blueprint("wallets_endpoint_api", __name__)
 
+get_txout_set_info_lock = threading.Lock()
+
 
 @wallets_endpoint_api.route("/wallets_loading/", methods=["GET", "POST"])
 @login_required
@@ -67,8 +71,17 @@ def generatemnemonic():
 @login_required
 @app.csrf.exempt
 def txout_set_info():
-    res = app.specter.rpc.gettxoutsetinfo(timeout=3600)
-    return res
+    if get_txout_set_info_lock.locked():
+        return {
+            "error": "Run the numbers is quite work intensive and there is already a call running. Stay calm and let it do its work!"
+        }, 429
+    with get_txout_set_info_lock:
+        try:
+            res = app.specter.rpc.gettxoutsetinfo(timeout=3600)
+            return res, 200
+        except Exception as e:
+            logger.exception(e)
+            return {"error": str(e)}, 429
 
 
 @wallets_endpoint_api.route("/get_scantxoutset_status")
@@ -243,7 +256,24 @@ def decoderawtx(wallet_alias):
         wallet: Wallet = app.specter.wallet_manager.get_by_alias(wallet_alias)
         txid = request.form.get("txid", "")
         if txid:
-            tx = wallet.rpc.gettransaction(txid)
+            try:
+                tx = wallet.rpc.gettransaction(txid)
+            except RpcError as e:
+                if "Invalid or non-wallet transaction id" in str(e):
+                    # Expected failure when looking up a txid that didn't originate from the
+                    # user's Wallet.
+                    logger.info(
+                        "Looking up a txid that didn't originate from the user's wallet. Can't return any tx data."
+                    )
+                    return jsonify(
+                        success=False,
+                        nonWalletTxId=True,
+                    )
+                else:
+                    logger.warning(
+                        "Failed to fetch transaction data. Exception: {}".format(e)
+                    )
+                    return jsonify(success=False)
             # This is a fix for Bitcoin Core versions < v0.20
             # These do not return the blockheight as part of the `gettransaction` command
             # So here we check if this property is lacking and if so
@@ -297,15 +327,6 @@ def decoderawtx(wallet_alias):
                 rawtx=rawtx,
                 walletName=wallet.name,
             )
-    except RpcError as e:
-        if "Invalid or non-wallet transaction id" in str(e):
-            # Expected failure when looking up a txid that didn't originate from the
-            #   user's Wallet.
-            pass
-        else:
-            app.logger.warning(
-                "Failed to fetch transaction data. Exception: {}".format(e)
-            )
     except Exception as e:
         app.logger.warning("Failed to fetch transaction data. Exception: {}".format(e))
 
@@ -657,6 +678,24 @@ def utxo_csv(wallet_alias):
         return _("Failed to export wallet utxo. Error: {}").format(e), 500
 
 
+@wallets_endpoint_api.route(
+    "/wallet/<wallet_alias>/is_address_mine/<address>", methods=["GET"]
+)
+@login_required
+def is_address_mine(wallet_alias, address):
+    wallet = app.specter.wallet_manager.get_by_alias(wallet_alias)
+
+    # filter out invalid input
+    if (not address) or not isinstance(address, str):
+        return jsonify(False)
+
+    # Segwit addresses are always between 14 and 74 characters long.
+    if len(address) < 14:
+        return jsonify(False)
+
+    return jsonify(wallet.is_address_mine(address))
+
+
 @wallets_endpoint_api.route("/wallet/<wallet_alias>/send/estimatefee", methods=["POST"])
 @login_required
 def estimate_fee(wallet_alias):
