@@ -1,15 +1,17 @@
 import json
 import logging
+
 import requests
-from cryptoadvance.specter.managers.wallet_manager import WalletManager
-
-from cryptoadvance.specter.specter_error import SpecterError
-
 from embit.descriptor import Descriptor
 from embit.descriptor import Key as DescriptorKey
 from embit.descriptor.arguments import AllowedDerivation
 from embit.liquid.descriptor import LDescriptor
-from cryptoadvance.specter.key import Key
+from flask_babel import lazy_gettext as _
+
+from ..key import Key
+from ..managers.wallet_manager import WalletManager
+from ..server_endpoints import flash
+from ..specter_error import SpecterError
 
 logger = logging.getLogger(__name__)
 
@@ -266,7 +268,19 @@ class WalletImporter:
                 xpubs += "[{}]{}/0/*,".format(
                     d["derivation"].replace("m", d["root_fingerprint"]), d["xpub"]
                 )
-                cosigners_types.append({"type": d["hw_type"], "label": d["label"]})
+                if "hw_type" in d:
+                    cosigners_types.append({"type": d["hw_type"], "label": d["label"]})
+                else:  # this can occcur if no hardware wallet was used, but the seed is available
+                    cosigners_types.append(
+                        {"type": "electrum", "label": f"Electrum Multisig {i}"}
+                    )
+                    if "seed" in d:
+                        flash(
+                            _(
+                                "The Electrum wallet contains a seed. The seed will not be imported."
+                            ),
+                            "warning",
+                        )
                 i += 1
             xpubs = xpubs.rstrip(",")
 
@@ -278,7 +292,7 @@ class WalletImporter:
                 raise Exception('"xpub" not found in "x1/" in Electrum backup json')
 
             required_sigs = int(wallet_data.get("wallet_type").split("of")[0])
-            recv_descriptor = "{}(sortedmulti({}, {}))".format(
+            recv_descriptor = "{}(sortedmulti({},{}))".format(
                 wallet_type, required_sigs, xpubs
             )
             wallet_name = "Electrum {} of {}".format(required_sigs, i - 1)
@@ -429,7 +443,7 @@ class WalletImporter:
                 )
             recv_descriptor = "{}({})".format(
                 wallet_type,
-                "[{}]{}/0/*,".format(
+                "[{}]{}/0/*".format(
                     wallet_data["keystore"]["derivation"].replace(
                         "m", wallet_data["keystore"]["root_fingerprint"]
                     ),
@@ -442,7 +456,13 @@ class WalletImporter:
                     "label": wallet_data["keystore"].get("label", "Electrum Wallet"),
                 }
             ]
-
+            if "seed" in wallet_data["keystore"]:
+                flash(
+                    _(
+                        "The Electrum wallet contains a seed. The seed will not be imported."
+                    ),
+                    "warning",
+                )
         # Current Specter backups
         else:
             # Newer exports are able to reinitialize device types but stay backwards
